==> arctrl-2.0.0a3.tar.gz: arctrl-2.0.0a3/arctrl/fable_modules/fs_spreadsheet/DSL/expression.py <==
from __future__ import annotations
from typing import (Any, Generic, TypeVar)
from ...fable_library.reflection import (TypeInfo, class_type)

_T = TypeVar("_T")

def _expr95(gen0: TypeInfo) -> TypeInfo:
    return class_type("FsSpreadsheet.DSL.Expression.OptionalSource`1", [gen0], OptionalSource_1)


class OptionalSource_1(Generic[_T]):
    def __init__(self, s: Any | None=None) -> None:
        self.s: _T = s


OptionalSource_1_reflection = _expr95

def OptionalSource_1__ctor_2B595(s: Any | None=None) -> OptionalSource_1[_T]:
    return OptionalSource_1(s)


def OptionalSource_1__get_Source(this: OptionalSource_1[_T]) -> _T:
    return this.s


def _expr96(gen0: TypeInfo) -> TypeInfo:
    return class_type("FsSpreadsheet.DSL.Expression.RequiredSource`1", [gen0], RequiredSource_1)


class RequiredSource_1(Generic[_T]):
    def __init__(self, s: Any | None=None) -> None:
        self.s: _T = s


RequiredSource_1_reflection = _expr96

def RequiredSource_1__ctor_2B595(s: Any | None=None) -> RequiredSource_1[_T]:
    return RequiredSource_1(s)


def RequiredSource_1__get_Source(this: RequiredSource_1[_T]) -> _T:
    return this.s


def _expr97(gen0: TypeInfo) -> TypeInfo:
    return class_type("FsSpreadsheet.DSL.Expression.ExpressionSource`1", [gen0], ExpressionSource_1)


class ExpressionSource_1(Generic[_T]):
    def __init__(self, s: Any | None=None) -> None:
        self.s: _T = s


ExpressionSource_1_reflection = _expr97

def ExpressionSource_1__ctor_2B595(s: Any | None=None) -> ExpressionSource_1[_T]:
    return ExpressionSource_1(s)


def ExpressionSource_1__get_Source(this: ExpressionSource_1[_T]) -> _T:
    return this.s


__all__ = ["OptionalSource_1_reflection", "OptionalSource_1__get_Source", "RequiredSource_1_reflection", "RequiredSource_1__get_Source", "ExpressionSource_1_reflection", "ExpressionSource_1__get_Source"]

==> arctrl-2.1.0a1.tar.gz: arctrl-2.1.0a1/arctrl/fable_modules/fs_spreadsheet/DSL/expression.py <==
from __future__ import annotations
from typing import (Any, Generic, TypeVar)
from ...fable_library.reflection import (TypeInfo, class_type)

_T = TypeVar("_T")

def _expr210(gen0: TypeInfo) -> TypeInfo:
    return class_type("FsSpreadsheet.DSL.Expression.OptionalSource`1", [gen0], OptionalSource_1)


class OptionalSource_1(Generic[_T]):
    def __init__(self, s: Any | None=None) -> None:
        self.s: _T = s


OptionalSource_1_reflection = _expr210

def OptionalSource_1__ctor_2B595(s: Any | None=None) -> OptionalSource_1[_T]:
    return OptionalSource_1(s)


def OptionalSource_1__get_Source(this: OptionalSource_1[Any]) -> Any:
    return this.s


def _expr211(gen0: TypeInfo) -> TypeInfo:
    return class_type("FsSpreadsheet.DSL.Expression.RequiredSource`1", [gen0], RequiredSource_1)


class RequiredSource_1(Generic[_T]):
    def __init__(self, s: Any | None=None) -> None:
        self.s: _T = s


RequiredSource_1_reflection = _expr211

def RequiredSource_1__ctor_2B595(s: Any | None=None) -> RequiredSource_1[_T]:
    return RequiredSource_1(s)


def RequiredSource_1__get_Source(this: RequiredSource_1[Any]) -> Any:
    return this.s


def _expr212(gen0: TypeInfo) -> TypeInfo:
    return class_type("FsSpreadsheet.DSL.Expression.ExpressionSource`1", [gen0], ExpressionSource_1)


class ExpressionSource_1(Generic[_T]):
    def __init__(self, s: Any | None=None) -> None:
        self.s: _T = s


ExpressionSource_1_reflection = _expr212

def ExpressionSource_1__ctor_2B595(s: Any | None=None) -> ExpressionSource_1[_T]:
    return ExpressionSource_1(s)


def ExpressionSource_1__get_Source(this: ExpressionSource_1[Any]) -> Any:
    return this.s


__all__ = ["OptionalSource_1_reflection", "OptionalSource_1__get_Source", "RequiredSource_1_reflection", "RequiredSource_1__get_Source", "ExpressionSource_1_reflection", "ExpressionSource_1__get_Source"]
